/*
TrayButton.h						Copyright  2005 by George A. Nelson

By:  Tony Nelson  on  25 Jan 05		

Description:  Minimize an app to either a Taskbar Button or a Taskbar
	Notification ("SysTray") icon.  Can use a Tool window to hide the Taskbar
	Button or not change the window style.  In either case, the SysTray icon
	behaves much like a Taskbar button: single left-clicks minimize or restore
	the app's window, and right-click brings up the Window ("System") menu. 
	Usage is simple; we subclass the app's window to add our behaviors. 
	Inspired by Neal Stublen's Hyperlinks.cpp on CodeGuru.com.

	Minimizing to the SysTray is appropriate for apps whose purpose is to
	change the Windows User Experience in some way, say, adding a toolbar to
	some apps, or repurposing the Command Keys at the top of some keyboards. 
	As this is an odd place to minimize to, the user should be the one to
	choose where to display the button, via a menu item or a checkbox.  That
	setting should be saved as a preference (usually in the Registry), and
	should initially be set to a normal Taskbar button.

Usage:  Call InitTrayButton() in WinMain() with the main window still not
	visible (before calling ShowWindow(iCmdShow)).  Call SetTrayButton() when
	the user changes where to minimize the app.

*/

BOOL	InitTrayButton( HWND hwnd, int * iCmdShowp,
			BOOL minimizeToTray = FALSE, BOOL useToolKind = FALSE );
BOOL	SetTrayButton( HWND hwnd, BOOL minimizeToTray );
